#!/usr/bin/env python
# -*- coding: utf-8 -*-
"""Convert text from Serbian Cyrillic alphabet to Serbian Latin alphabet
"""

__author__ = "Janos Guljas"
__copyright__ = "Copyright (c) 2009, Janos Guljas"
__credits__ = ["Harry Kalogirou"]
__license__ = "GPL"
__version__ = "0.1"
__maintainer__ = "Janos Guljas"
__email__ = "janos@janos.in.rs"
__status__ = "Production"


import re, sys

MAP = {
    u'а':'a', u'б':'b', u'в':'v', u'г':'g', u'д':'d', u'ђ':'đ', u'е':'e',
    u'ж':'ž', u'з':'z', u'и':'i', u'ј':'j', u'к':'k', u'л':'l', u'љ':'lj',
    u'м':'m', u'н':'n', u'њ':'nj', u'о':'o', u'п':'p', u'р':'r', u'с':'s',
    u'т':'t', u'ћ':'ć', u'у':'u', u'ф':'f', u'џ':'x', u'ц':'c', u'ч':'č',
    u'џ':'dž', u'ш':'š',
    u'А':'A', u'Б':'B', u'В':'V', u'Г':'G', u'Д':'D', u'Ђ':'Đ', u'Е':'E',
    u'Ж':'Ž', u'З':'Z', u'И':'I', u'Ј':'J', u'К':'K', u'Л':'L', u'Љ':'Lj',
    u'М':'M', u'Н':'N', u'Њ':'Nj', u'О':'O', u'П':'P', u'Р':'R', u'С':'S',
    u'Т':'T', u'Ћ':'Ć', u'У':'u', u'Ф':'F', u'Џ':'X', u'Ц':'C', u'Ч':'Č',
    u'Џ':'Dž', u'Ш':'Š'
}

def _makeRegex():
    s = u"".join(MAP.keys())
    regex = re.compile(u"[%s]|[^%s]+" % (s,s))
    return MAP, regex

_MAPINGS = None
_regex = None

def recode(s):
	"""Function that converts charachers 
	"""
	global _MAPINGS, _regex
	if not _regex:
		_MAPINGS, _regex = _makeRegex()    
	recoded = ""
	for piece in _regex.findall(s):
		if _MAPINGS.has_key(piece):
			recoded += _MAPINGS[piece]
		else:
			recoded += piece.encode("utf-8")
	return recoded

def _help():
	print """NAME
    recode-cyr2lat - convert text from Serbian Cyrillic alphabet to 
                     Serbian Latin alphabet

SYNOPSIS
    recode-cyr2lat.py [OPTIONS]

DESCRIPTION
    Convert text from Serbian Cyrillic alphabet to Serbian Latin alphabet. The 
    input text is read from standard input, and the converted text is output to
    standard output. Encoding must be UTF-8.
    
OPTIONS
    -h
        Prints this help and exit
    -v
        Prints version information and exit


EXAMPLES
    recode-cyr2lat.py < input_cyrillic_file > output_latin_file
    echo "Јанош Гуљаш" | recode-cyr2lat.py

AUTOR
    Written by """ + __author__ + """ (http://www.janos.in.rs).

REPORTING BUGS
    Report bugs to <""" + __email__ + """>.

COPYRIGHT
    """ + __copyright__ + """.  License GPLv3+:
    GNU GPL version 3 or later <http://gnu.org/licenses/gpl.html>
    This is free software: you are free  to  change  and  redistribute  it.
    There is NO WARRANTY, to the extent permitted by law.
	"""

def _version():
	print "recode-cyr2lat", __version__

if __name__ == '__main__':
	if sys.stdin.isatty():
		if len(sys.argv) > 1:
			_v, _h = True, True
			for _argument in sys.argv:
				if _argument[0] == '-':
					for _option in _argument:
						if _option == '-':
							pass
						elif _option == 'v' and _v == True:
							_version()
							_v = False
						elif _option == 'h' and _h == True:
							_help()
							_h = False
						else:
							print "Unknown option -" + _option 
		else:
			_help()
		
	else:
		sys.stdout.write(recode(sys.stdin.read().decode("utf-8")))
